"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockStorage = void 0;
const client_utils_1 = require("@fluid-internal/client-utils");
const internal_1 = require("@fluidframework/core-utils/internal");
const internal_2 = require("@fluidframework/runtime-utils/internal");
/**
 * Mock implementation of IChannelStorageService based on ITree input.
 * @legacy
 * @alpha
 */
class MockStorage {
    static createFromSummary(summaryTree) {
        const tree = (0, internal_2.convertSummaryTreeToITree)(summaryTree);
        return new MockStorage(tree);
    }
    static readBlobCore(tree, paths) {
        if (tree) {
            for (const entry of tree.entries) {
                if (entry.path === paths[0]) {
                    if (entry.type === "Blob") {
                        // eslint-disable-next-line prefer-rest-params
                        (0, internal_1.assert)(paths.length === 1, JSON.stringify({ ...arguments }));
                        return entry.value;
                    }
                    if (entry.type === "Tree") {
                        return MockStorage.readBlobCore(entry.value, paths.slice(1));
                    }
                    return undefined;
                }
            }
            return undefined;
        }
    }
    constructor(tree) {
        this.tree = tree;
    }
    async readBlob(path) {
        const blob = MockStorage.readBlobCore(this.tree, path.split("/"));
        (0, internal_1.assert)(blob !== undefined, `Blob does not exist: ${path}`);
        return (0, client_utils_1.stringToBuffer)(blob.contents, blob.encoding);
    }
    async contains(path) {
        return MockStorage.readBlobCore(this.tree, path.split("/")) !== undefined;
    }
    async list(path) {
        return (0, internal_2.listBlobsAtTreePath)(this.tree, path);
    }
}
exports.MockStorage = MockStorage;
//# sourceMappingURL=mockStorage.js.map