"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockFluidDataStoreContext = void 0;
const internal_1 = require("@fluidframework/telemetry-utils/internal");
const uuid_1 = require("uuid");
const mockDeltas_js_1 = require("./mockDeltas.js");
/**
 * @legacy
 * @alpha
 */
class MockFluidDataStoreContext {
    constructor(id = (0, uuid_1.v4)(), existing = false, baseLogger = (0, internal_1.createChildLogger)({
        namespace: "fluid:MockFluidDataStoreContext",
    }), interactive = true) {
        this.id = id;
        this.existing = existing;
        this.baseLogger = baseLogger;
        this.isLocalDataStore = true;
        this.packagePath = undefined;
        this.options = {};
        this.clientId = (0, uuid_1.v4)();
        this.connected = true;
        this.readonly = false;
        this.deltaManager = new mockDeltas_js_1.MockDeltaManager(() => this.clientId);
        this.containerRuntime = undefined;
        this.storage = undefined;
        this.IFluidDataStoreRegistry = undefined;
        this.IFluidHandleContext = undefined;
        this.idCompressor = undefined;
        this.gcThrowOnTombstoneUsage = false;
        this.gcTombstoneEnforcementAllowed = false;
        /**
         * Indicates the attachment state of the data store to a host service.
         */
        this.attachState = undefined;
        this.scope = undefined;
        this.clientDetails = { capabilities: { interactive } };
    }
    on(event, listener) {
        switch (event) {
            case "attaching":
            case "attached":
                return this;
            default:
                throw new Error("Method not implemented.");
        }
    }
    once(event, listener) {
        return this;
    }
    off(event, listener) {
        throw new Error("Method not implemented.");
    }
    getQuorum() {
        return undefined;
    }
    getAudience() {
        return undefined;
    }
    submitMessage(type, content, localOpMetadata) {
        // No-op for mock context
    }
    submitSignal(type, content) {
        throw new Error("Method not implemented.");
    }
    makeLocallyVisible() {
        throw new Error("Method not implemented.");
    }
    setChannelDirty(address) {
        throw new Error("Method not implemented.");
    }
    async getAbsoluteUrl(relativeUrl) {
        throw new Error("Method not implemented.");
    }
    getCreateChildSummarizerNodeFn(id, createParam) {
        throw new Error("Method not implemented.");
    }
    deleteChildSummarizerNode(id) {
        throw new Error("Method not implemented.");
    }
    async uploadBlob(blob) {
        throw new Error("Method not implemented.");
    }
    async getBaseGCDetails() {
        throw new Error("Method not implemented.");
    }
    addedGCOutboundRoute(fromPath, toPath, messageTimestampMs) {
        throw new Error("Method not implemented.");
    }
}
exports.MockFluidDataStoreContext = MockFluidDataStoreContext;
//# sourceMappingURL=mocksDataStoreContext.js.map