/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { EventEmitter, TypedEventEmitter } from "@fluid-internal/client-utils";
import { IDeltaManager, IDeltaManagerEvents, IDeltaQueue, ReadOnlyInfo } from "@fluidframework/container-definitions/internal";
import { IClientDetails } from "@fluidframework/driver-definitions";
import { IClientConfiguration, IDocumentMessage, MessageType, ISequencedDocumentMessage, ISignalMessage } from "@fluidframework/driver-definitions/internal";
/**
 * Mock implementation of IDeltaQueue for testing that does nothing
 * @legacy
 * @alpha
 */
export declare class MockDeltaQueue<T> extends EventEmitter implements IDeltaQueue<T> {
    protected readonly queue: T[];
    protected pauseCount: number;
    processCallback: (el: T) => void;
    get disposed(): any;
    get paused(): boolean;
    get length(): number;
    get idle(): boolean;
    protected process(): void;
    push(el: T): void;
    pop(): T | undefined;
    pause(): Promise<void>;
    resume(): void;
    peek(): T | undefined;
    toArray(): T[];
    dispose(): void;
    waitTillProcessingDone(): Promise<{
        count: number;
        duration: number;
    }>;
    constructor();
}
/**
 * Mock implementation of IDeltaManager for testing that creates mock DeltaQueues for testing
 * @legacy
 * @alpha
 */
export declare class MockDeltaManager extends TypedEventEmitter<IDeltaManagerEvents> implements IDeltaManager<ISequencedDocumentMessage, IDocumentMessage> {
    private readonly getClientId?;
    get disposed(): any;
    readOnlyInfo: ReadOnlyInfo;
    readonly clientType: string;
    readonly clientDetails: IClientDetails;
    get IDeltaSender(): this;
    private readonly _inbound;
    private readonly _inboundSignal;
    private readonly _outbound;
    get inbound(): MockDeltaQueue<ISequencedDocumentMessage>;
    get outbound(): MockDeltaQueue<IDocumentMessage[]>;
    get inboundSignal(): MockDeltaQueue<ISignalMessage>;
    minimumSequenceNumber: number;
    lastSequenceNumber: number;
    lastMessage: ISequencedDocumentMessage | undefined;
    readonly lastKnownSeqNumber = 0;
    initialSequenceNumber: number;
    hasCheckpointSequenceNumber: boolean;
    get version(): string;
    readonly maxMessageSize: number;
    get serviceConfiguration(): IClientConfiguration;
    active: boolean;
    close(): void;
    submitSignal(content: any): void;
    flush(): void;
    submit(type: MessageType, contents: any, batch: boolean | undefined, localOpMetadata: any): number;
    dispose(): void;
    clientSequenceNumber: number;
    process(message: ISequencedDocumentMessage): void;
    constructor(getClientId?: (() => string | undefined) | undefined);
}
//# sourceMappingURL=mockDeltas.d.ts.map