/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { EventEmitter, TypedEventEmitter } from "@fluid-internal/client-utils";
import { assert } from "@fluidframework/core-utils/internal";
/**
 * Mock implementation of IDeltaQueue for testing that does nothing
 * @legacy
 * @alpha
 */
export class MockDeltaQueue extends EventEmitter {
    get disposed() {
        return undefined;
    }
    get paused() {
        return this.pauseCount !== 0;
    }
    get length() {
        return this.queue.length;
    }
    get idle() {
        return this.queue.length === 0;
    }
    process() {
        void Promise.resolve().then(() => {
            while (this.pauseCount === 0 && this.length > 0) {
                const el = this.pop();
                assert(el !== undefined, "this is impossible due to the above length check");
                this.processCallback(el);
            }
        });
    }
    push(el) {
        this.queue.push(el);
        this.emit("push", el);
        this.process();
    }
    pop() {
        return this.queue.shift();
    }
    async pause() {
        this.pauseCount++;
        return;
    }
    resume() {
        this.pauseCount--;
        this.process();
    }
    peek() {
        return this.queue[0];
    }
    toArray() {
        return this.queue;
    }
    dispose() { }
    async waitTillProcessingDone() {
        throw new Error("NYI");
    }
    constructor() {
        super();
        this.queue = [];
        this.pauseCount = 0;
        this.processCallback = () => { };
    }
}
/**
 * Mock implementation of IDeltaManager for testing that creates mock DeltaQueues for testing
 * @legacy
 * @alpha
 */
export class MockDeltaManager extends TypedEventEmitter {
    get disposed() {
        return undefined;
    }
    get IDeltaSender() {
        return this;
    }
    get inbound() {
        return this._inbound;
    }
    get outbound() {
        return this._outbound;
    }
    get inboundSignal() {
        return this._inboundSignal;
    }
    get version() {
        return undefined;
    }
    get serviceConfiguration() {
        return undefined;
    }
    close() { }
    submitSignal(content) { }
    flush() { }
    submit(type, contents, batch = false, localOpMetadata) {
        return 0;
    }
    dispose() {
        this.removeAllListeners();
    }
    process(message) {
        assert(message.sequenceNumber !== undefined, "message missing sequenceNumber");
        assert(message.minimumSequenceNumber !== undefined, "message missing minimumSequenceNumber");
        this.lastSequenceNumber = message.sequenceNumber;
        this.lastMessage = message;
        this.minimumSequenceNumber = message.minimumSequenceNumber;
        this.emit("op", message);
    }
    constructor(getClientId) {
        super();
        this.getClientId = getClientId;
        this.readOnlyInfo = { readonly: false };
        this.clientType = undefined;
        this.clientDetails = {};
        this._inbound = undefined;
        this._inboundSignal = undefined;
        this._outbound = undefined;
        this.minimumSequenceNumber = 0;
        this.lastSequenceNumber = 0;
        this.lastKnownSeqNumber = 0;
        this.initialSequenceNumber = 0;
        this.hasCheckpointSequenceNumber = false;
        this.maxMessageSize = 0;
        this.active = true;
        this.clientSequenceNumber = 0;
        this._inbound = new MockDeltaQueue();
        this._outbound = new MockDeltaQueue();
        this._outbound.on("push", (messages) => {
            messages.forEach((message) => {
                // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
                this._inbound.push({
                    ...message,
                    clientId: this.getClientId?.() ?? null,
                    // ! sequenceNumber and minimumSequenceNumber should be added by MockContainerRuntimeFactory
                });
            });
        });
        this._inboundSignal = new MockDeltaQueue();
    }
}
//# sourceMappingURL=mockDeltas.js.map