/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { stringToBuffer } from "@fluid-internal/client-utils";
import { assert } from "@fluidframework/core-utils/internal";
import { convertSummaryTreeToITree, listBlobsAtTreePath, } from "@fluidframework/runtime-utils/internal";
/**
 * Mock implementation of IChannelStorageService based on ITree input.
 * @legacy
 * @alpha
 */
export class MockStorage {
    static createFromSummary(summaryTree) {
        const tree = convertSummaryTreeToITree(summaryTree);
        return new MockStorage(tree);
    }
    static readBlobCore(tree, paths) {
        if (tree) {
            for (const entry of tree.entries) {
                if (entry.path === paths[0]) {
                    if (entry.type === "Blob") {
                        // eslint-disable-next-line prefer-rest-params
                        assert(paths.length === 1, JSON.stringify({ ...arguments }));
                        return entry.value;
                    }
                    if (entry.type === "Tree") {
                        return MockStorage.readBlobCore(entry.value, paths.slice(1));
                    }
                    return undefined;
                }
            }
            return undefined;
        }
    }
    constructor(tree) {
        this.tree = tree;
    }
    async readBlob(path) {
        const blob = MockStorage.readBlobCore(this.tree, path.split("/"));
        assert(blob !== undefined, `Blob does not exist: ${path}`);
        return stringToBuffer(blob.contents, blob.encoding);
    }
    async contains(path) {
        return MockStorage.readBlobCore(this.tree, path.split("/")) !== undefined;
    }
    async list(path) {
        return listBlobsAtTreePath(this.tree, path);
    }
}
//# sourceMappingURL=mockStorage.js.map