/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { AttachState, IAudience } from "@fluidframework/container-definitions";
import { IDeltaManager } from "@fluidframework/container-definitions/internal";
import { FluidObject } from "@fluidframework/core-interfaces";
import { IFluidHandleContext, type IFluidHandleInternal } from "@fluidframework/core-interfaces/internal";
import { IClientDetails, IQuorumClients } from "@fluidframework/driver-definitions";
import { IDocumentStorageService, IDocumentMessage, ISnapshotTree, ISequencedDocumentMessage } from "@fluidframework/driver-definitions/internal";
import type { IIdCompressor } from "@fluidframework/id-compressor";
import type { IIdCompressorCore } from "@fluidframework/id-compressor/internal";
import { CreateChildSummarizerNodeFn, CreateChildSummarizerNodeParam, IContainerRuntimeBase, IFluidDataStoreContext, IFluidDataStoreRegistry, IGarbageCollectionDetailsBase } from "@fluidframework/runtime-definitions/internal";
import { ITelemetryLoggerExt } from "@fluidframework/telemetry-utils/internal";
/**
 * @legacy
 * @alpha
 */
export declare class MockFluidDataStoreContext implements IFluidDataStoreContext {
    readonly id: string;
    readonly existing: boolean;
    readonly baseLogger: ITelemetryLoggerExt;
    isLocalDataStore: boolean;
    packagePath: readonly string[];
    options: Record<string | number, any>;
    clientId: string | undefined;
    clientDetails: IClientDetails;
    connected: boolean;
    readonly: boolean;
    baseSnapshot: ISnapshotTree | undefined;
    deltaManager: IDeltaManager<ISequencedDocumentMessage, IDocumentMessage>;
    containerRuntime: IContainerRuntimeBase;
    storage: IDocumentStorageService;
    IFluidDataStoreRegistry: IFluidDataStoreRegistry;
    IFluidHandleContext: IFluidHandleContext;
    idCompressor: IIdCompressorCore & IIdCompressor;
    readonly gcThrowOnTombstoneUsage = false;
    readonly gcTombstoneEnforcementAllowed = false;
    /**
     * @remarks This is for internal use only.
     */
    ILayerCompatDetails?: unknown;
    /**
     * Indicates the attachment state of the data store to a host service.
     */
    attachState: AttachState;
    /**
     * @deprecated 0.16 Issue #1635, #3631
     */
    createProps?: any;
    scope: FluidObject;
    constructor(id?: string, existing?: boolean, baseLogger?: ITelemetryLoggerExt, interactive?: boolean);
    on(event: string | symbol, listener: (...args: any[]) => void): this;
    once(event: string | symbol, listener: (...args: any[]) => void): this;
    off(event: string | symbol, listener: (...args: any[]) => void): this;
    getQuorum(): IQuorumClients;
    getAudience(): IAudience;
    submitMessage(type: string, content: any, localOpMetadata: unknown): void;
    submitSignal(type: string, content: any): void;
    makeLocallyVisible(): void;
    setChannelDirty(address: string): void;
    getAbsoluteUrl(relativeUrl: string): Promise<string | undefined>;
    getCreateChildSummarizerNodeFn(id: string, createParam: CreateChildSummarizerNodeParam): CreateChildSummarizerNodeFn;
    deleteChildSummarizerNode(id: string): void;
    uploadBlob(blob: ArrayBufferLike): Promise<IFluidHandleInternal<ArrayBufferLike>>;
    getBaseGCDetails(): Promise<IGarbageCollectionDetailsBase>;
    addedGCOutboundRoute(fromPath: string, toPath: string, messageTimestampMs?: number): void;
}
//# sourceMappingURL=mocksDataStoreContext.d.ts.map