/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ISequencedDocumentMessage } from "@fluidframework/driver-definitions/internal";
import { IMockContainerRuntimeOptions, MockContainerRuntime, MockContainerRuntimeFactory, MockFluidDataStoreRuntime } from "./mocks.js";
/**
 * Specialized implementation of MockContainerRuntime for testing ops during reconnection.
 * @legacy
 * @alpha
 */
export declare class MockContainerRuntimeForReconnection extends MockContainerRuntime {
    protected readonly factory: MockContainerRuntimeFactoryForReconnection;
    /**
     * Contains messages from other clients that were sequenced while this runtime was marked as disconnected.
     */
    protected readonly pendingRemoteMessages: ISequencedDocumentMessage[];
    /**
     * Returns the connection state of the container runtime.
     * Any messages that are submitted while not connected will be resubmitted via the resubmit flow on reconnection.
     * Any messages received while disconnected will be processed on reconnection.
     * Also, the clientId of the runtime will change on reconnection.
     */
    get connected(): boolean;
    set connected(connected: boolean);
    protected processPendingMessages(pendingMessages: ISequencedDocumentMessage[]): void;
    protected setConnectedState(connected: boolean): void;
    private _connected;
    protected readonly processedOps?: ISequencedDocumentMessage[];
    constructor(dataStoreRuntime: MockFluidDataStoreRuntime, factory: MockContainerRuntimeFactoryForReconnection, runtimeOptions?: IMockContainerRuntimeOptions, overrides?: {
        minimumSequenceNumber?: number;
        trackRemoteOps?: boolean;
    });
    process(message: ISequencedDocumentMessage): void;
    submit(messageContent: any, localOpMetadata: unknown): number;
    flush(): void;
    initializeWithStashedOps(fromContainerRuntime: MockContainerRuntimeForReconnection): Promise<void>;
}
/**
 * Specialized implementation of MockContainerRuntimeFactory for testing ops during reconnection.
 * @legacy
 * @alpha
 */
export declare class MockContainerRuntimeFactoryForReconnection extends MockContainerRuntimeFactory {
    createContainerRuntime(dataStoreRuntime: MockFluidDataStoreRuntime, overrides?: {
        minimumSequenceNumber?: number;
        trackRemoteOps?: boolean;
    }): MockContainerRuntimeForReconnection;
    clearOutstandingClientMessages(clientId: string): void;
}
//# sourceMappingURL=mocksForReconnection.d.ts.map